Relazioni | OiRA

Temi

# Relazioni

Puoi usare le relazioni per:

- fornire prove alle autorità di vigilanza;
- trasmettere informazioni alle persone interessate (lavoratori, rappresentanti degli addetti alla sicurezza, datori di lavoro, esperti di sicurezza e salute sul lavoro ecc.);
- verificare e valutare se siano state adottate le misure necessarie;
- registrare tutte le modifiche dovute a cambiamenti delle circostanze (macchine/lavoratori nuovi) oppure agli esiti di indagini su incidenti ecc.

Puoi salvare la relazione sul computer e stamparla. Puoi anche modificarla o aggiungere ulteriori informazioni. Tieni presente che qualsiasi modifica apportata a una relazione dopo averla scaricata NON sarà salvata nello strumento OiRA.

## Tipi di relazioni

Sono disponibili vari tipi di relazioni, a seconda delle differenti finalità. I tipi di relazioni disponibili per i vari strumenti specifici dipendono dalle decisioni adottate dal partner OiRA/dallo sviluppatore dello strumento nazionale.

Le relazioni disponibili.

### Relazione completa

Formato: Word / Office Open XML (.docx). Può essere modificata dopo averla scaricata.

Contiene: tutte le informazioni e i contributi che hai inserito durante l’intero procedimento di valutazione dei rischi.

Utilizzala per: fornire alle autorità di vigilanza (ad esempio l’ispettorato del lavoro) prove dell’esecuzione della valutazione dei rischi.

### Piano d’azione

Formato: Excel / Office Open XML (.xlsx). Può essere modificato dopo averlo scaricato.

Contiene: informazioni su tutte le misure che hai deciso di attuare.

Utilizzala per:

- dare attivamente seguito all’esecuzione delle misure prescelte;
- gestire i problemi/rischi sul posto di lavoro (compiti specifici, competenze, responsabilità, scadenze).

### Panoramica dei rischi

Formato: Portable Document Format (.pdf). Non può essere modificata dopo averla scaricata.

Contiene: una panoramica dei rischi individuati.

Utilizzala per:

- avere una rapida panoramica dello stato dei rischi sul luogo di lavoro;
- trasmettere informazioni alle persone interessate;
- verificare se i rischi/le misure sono gestiti correttamente.

### Panoramica delle misure

Formato: Portable Document Format (.pdf). Non può essere modificata dopo averla scaricata.

Contiene: una rapida panoramica delle misure da attuare.

Utilizzala per:

- avere una rapida panoramica dello stato delle misure che hai deciso di attuare;
- trasmettere informazioni alle persone interessate;
- verificare se i rischi/le misure sono gestiti correttamente.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More